@@ -16,6 +16,8 @@ def get_markdown_images(text):
     :return:
     """
     image_arr = re.findall(r'(?:!\[(.*?)\]\((.*?)\))', text)  # 提最述与rul
+    # image_arr = re.findall(r'!\[(.*)\]\((.+)\)', text)  # 提最述与rul
+
     # print("image_arr", image_arr)
     return image_arr
 def get_markdown_images_format(text):
@@ -60,12 +62,33 @@ def auto_request(payload, api, timeout=600):
     # payload = json.dumps(payload, ensure_ascii=False)
     # print("auto_request", json.dumps(payload, ensure_ascii=False))
     # headers = {'accept: application/json'}
-    headers = None
-    response = requests.post(
-        api, json=payload, headers=headers, timeout=timeout)
-    # print(response.text)
+    # headers = None
+    # response = requests.post(
+    #     api, json=payload, headers=headers, timeout=timeout)
+    # # print(response.text)
+
+
+    headers = {
+        "content-type": "application/json",
+        "Accept": "application/json",
+
+    }
+    # response = requests.request("POST", url, json=payload, headers=headers)
+
+    response = requests.request("POST", api,data=json.dumps(payload), headers=headers)
+    assert response.status_code==200
     return response.json()
 
+# def decode_summary_text(data):
+#     data={
+#     "results": [
+#         [
+#         {
+#             "summary_text": "Benefits of CBD Oil for Dogs .<n>The Benefits of Coconut Oil for Your Dog .<n>How to Deal with DogAnxiety in Car Rides ."
+#         }
+#         ]
+#     ]
+#     }
 
 class SentenceClassification(object):
     """
@@ -157,7 +180,7 @@ class AutoReWrite(object):
         api = f"{self.api_host}/predict_en_summary"
         return auto_request(payload, api, timeout)
 
-    def auto_summary(self, text,auto_sample=False,temperature=1.15, **kwargs):
+    def auto_summary(self, text,auto_sample=False,temperature=1.15,config=None, **kwargs):
         """
         自动生成摘要，设置了默认参数
 
@@ -194,20 +217,33 @@ class AutoReWrite(object):
         # }, "text": [text]}
 
         # 自动调参 https://wandb.ai/terrychanorg/uncategorized/sweeps/j64ghxnf?workspace=user-terrychanorg
-        config={"do_sample": True,
-                    "max_length": min(mi,128),
-                    "early_stopping":True,
-                    "num_return_sequences": 5,
-                    "no_repeat_ngram_size":5,
-                    "num_beams":8,
-                    "temperature":0.7773100411930902,
-                    "top_p":0.7735368770052764,
-                    "top_k": 100
-                    }
+        # config={"do_sample": True,
+        #             "max_length": min(mi,128),
+        #             "early_stopping":True,
+        #             "num_return_sequences": 5,
+        #             "no_repeat_ngram_size":5,
+        #             "num_beams":8,
+        #             "temperature":0.7773100411930902,
+        #             "top_p":0.7735368770052764,
+        #             "top_k": 50
+        #             }
+
+        #new1 for cnn
+        if config is None:
+            config={"do_sample": True,
+                "max_length": min(mi,128),
+                "early_stopping":True,
+                "num_return_sequences": 5,
+                "no_repeat_ngram_size":5,
+                "num_beams":6,
+                "temperature":0.8532525677925238,
+                "top_p":0.5793650747162632,
+                # "top_k": 50
+                }
         payload={"config":config,
                  "text": [text]
                  }
-        return self.predict_summary(payload, timeout=1200)
+        return self.predict_summary(payload, timeout=600)
         # pass
 
     def predict_title(self, payload, timeout=600):
@@ -573,6 +609,8 @@ class AutoReWrite(object):
         # print("".join(new), "\n")
         return {"items": newdata, "images": images_list}
 
+
+
     def rewriter_by_summary(self, text, simlimit=0.8, num_beams=5, num_return_sequences=5, max_length=128, simlimitmax=1.0,
                  auto_sample=False,temperature=1.1125, pre_text="", **kwargs):
         """
@@ -604,24 +642,36 @@ class AutoReWrite(object):
         # for p in text.split('\n'):
         # 自动拆分段落，并且对文本中的图像进行分割为单独段落。
         ps,imgs=get_markdown_images_format(text)
-        for p,images in tqdm(zip(ps,imgs)):
+        p_list=[]
+        for p_text,images in tqdm(zip(ps,imgs)):
+
+            # 拼接段落，防止出现过短的段落出现
+            p_list.append(p_text)
+            if len("\n".join(p_list).split(" "))>128:
+                p="\n".join(p_list)
+                p_list=[]
+            else:
+                continue
+
             # 判断是否存在图片，如果存在图片则不做重写
             # images = get_markdown_images(p)
-            if images is None and len(p)>0:
-                # print("p",p)
-                out=self.auto_summary(p,auto_sample=True,temperature=temperature)
+            if images is None and len(p)>0 and p is not None:
+                # print("p===================\n",p)
+
+
                 try:
-                    if out.get("results") and type(out)==dict:
+                    out=self.auto_summary(p,auto_sample=True,temperature=temperature)
+                except Exception as e:
+                    pass
+                # print(out)
+                try:
+                    if out.get("results") and type(out)==dict and out['results'][0][0]['summary_text'] is not None:
 
                         newdata.append(out['results'][0][0]['summary_text'])
-                    else:
-                        newdata.append(p)
+                    # else:
+                    #     newdata.append(p)
                 except Exception as e:
-                #     print("Error creating",e)
-                #     print(out)
-                #     print(type(out))
-
-                    if type(out)==dict:
+                    if type(out)==dict and out['results'][0][0][0]['summary_text'] is not None:
 
                         newdata.append(out['results'][0][0][0]['summary_text'])
 
@@ -629,7 +679,7 @@ class AutoReWrite(object):
                         newdata.append(p)
             else:
                 newdata.append(p)
-                images_list = images_list + images
+                images_list.append(images)
             newdata.append("\n")
         # print(text, "\n")
         # print("".join(new), "\n")
@@ -648,25 +698,10 @@ def rewriter_by_summary(text,auto_sample=False,simlimit=0.6,temperature=1.2,api=
     # for temperature in [1.2]:
     out = rewriter.rewriter_by_summary(text, simlimit=0.6, simlimitmax=0.999999999, auto_sample=False,temperature=temperature)
 
-    # print("temperature",temperature)
-    # # print(text)
-    # print("".join(out['items']))
-    # ratio = similar_diff_qk_ratio(text, "".join(out['items']))
-    # print(ratio)
-    # print("字数",len(" ".join(out['items']).split(" ")))
-
-
     text="\n ".join(out['items'])
     text= auto_text_tilling(text)
     # 提取图片信息
     text_list,images=get_markdown_images_format(text)
-    # print(text_list)
-
-    # for text,image in zip(text_list,images):
-    #     if image is None:
-    #         print(text)
-    #     else:
-    #         print(image)
     return text_list,images
 
 if __name__ == "__main__":
